==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/BarcodeType.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BarcodeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="BarcodeType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/extraction/barcode}PositionedContentElementType">
 *       <attGroup ref="{http://schema.webpdf.de/1.0/extraction/barcode}optionalBarcodeAttributes"/>
 *       <attribute name="type" use="required" type="{http://schema.webpdf.de/1.0/extraction/barcode}BarcodeEncodingsType" />
 *       <attribute name="page" default="1">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BarcodeType")
public class BarcodeType
    extends PositionedContentElementType
{

    @XmlAttribute(name = "type", required = true)
    protected BarcodeEncodingsType type;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "errorCorrectionLevel")
    protected String errorCorrectionLevel;
    @XmlAttribute(name = "segmentIndex")
    protected String segmentIndex;
    @XmlAttribute(name = "isLastSegment")
    protected String isLastSegment;
    @XmlAttribute(name = "optionalData")
    protected String optionalData;
    @XmlAttribute(name = "fileId")
    protected String fileId;
    @XmlAttribute(name = "structuredAppendParity")
    protected String structuredAppendParity;
    @XmlAttribute(name = "structuredAppendSequence")
    protected String structuredAppendSequence;
    @XmlAttribute(name = "pdf417ExtraMetadata")
    protected String pdf417ExtraMetadata;
    @XmlAttribute(name = "upcEanExtension")
    protected String upcEanExtension;
    @XmlAttribute(name = "suggestedPrice")
    protected String suggestedPrice;
    @XmlAttribute(name = "issueNumber")
    protected String issueNumber;
    @XmlAttribute(name = "orientation")
    protected String orientation;
    @XmlAttribute(name = "other")
    protected String other;
    @XmlAttribute(name = "possibleCountry")
    protected String possibleCountry;

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link BarcodeEncodingsType }
     *     
     */
    public BarcodeEncodingsType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link BarcodeEncodingsType }
     *     
     */
    public void setType(BarcodeEncodingsType value) {
        this.type = value;
    }

    public boolean isSetType() {
        return (this.type!= null);
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  1;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the errorCorrectionLevel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorCorrectionLevel() {
        if (errorCorrectionLevel == null) {
            return "";
        } else {
            return errorCorrectionLevel;
        }
    }

    /**
     * Sets the value of the errorCorrectionLevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorCorrectionLevel(String value) {
        this.errorCorrectionLevel = value;
    }

    public boolean isSetErrorCorrectionLevel() {
        return (this.errorCorrectionLevel!= null);
    }

    /**
     * Gets the value of the segmentIndex property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSegmentIndex() {
        if (segmentIndex == null) {
            return "";
        } else {
            return segmentIndex;
        }
    }

    /**
     * Sets the value of the segmentIndex property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSegmentIndex(String value) {
        this.segmentIndex = value;
    }

    public boolean isSetSegmentIndex() {
        return (this.segmentIndex!= null);
    }

    /**
     * Gets the value of the isLastSegment property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsLastSegment() {
        if (isLastSegment == null) {
            return "";
        } else {
            return isLastSegment;
        }
    }

    /**
     * Sets the value of the isLastSegment property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsLastSegment(String value) {
        this.isLastSegment = value;
    }

    public boolean isSetIsLastSegment() {
        return (this.isLastSegment!= null);
    }

    /**
     * Gets the value of the optionalData property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOptionalData() {
        if (optionalData == null) {
            return "";
        } else {
            return optionalData;
        }
    }

    /**
     * Sets the value of the optionalData property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOptionalData(String value) {
        this.optionalData = value;
    }

    public boolean isSetOptionalData() {
        return (this.optionalData!= null);
    }

    /**
     * Gets the value of the fileId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFileId() {
        if (fileId == null) {
            return "";
        } else {
            return fileId;
        }
    }

    /**
     * Sets the value of the fileId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFileId(String value) {
        this.fileId = value;
    }

    public boolean isSetFileId() {
        return (this.fileId!= null);
    }

    /**
     * Gets the value of the structuredAppendParity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStructuredAppendParity() {
        if (structuredAppendParity == null) {
            return "";
        } else {
            return structuredAppendParity;
        }
    }

    /**
     * Sets the value of the structuredAppendParity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStructuredAppendParity(String value) {
        this.structuredAppendParity = value;
    }

    public boolean isSetStructuredAppendParity() {
        return (this.structuredAppendParity!= null);
    }

    /**
     * Gets the value of the structuredAppendSequence property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStructuredAppendSequence() {
        if (structuredAppendSequence == null) {
            return "";
        } else {
            return structuredAppendSequence;
        }
    }

    /**
     * Sets the value of the structuredAppendSequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStructuredAppendSequence(String value) {
        this.structuredAppendSequence = value;
    }

    public boolean isSetStructuredAppendSequence() {
        return (this.structuredAppendSequence!= null);
    }

    /**
     * Gets the value of the pdf417ExtraMetadata property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPdf417ExtraMetadata() {
        if (pdf417ExtraMetadata == null) {
            return "";
        } else {
            return pdf417ExtraMetadata;
        }
    }

    /**
     * Sets the value of the pdf417ExtraMetadata property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPdf417ExtraMetadata(String value) {
        this.pdf417ExtraMetadata = value;
    }

    public boolean isSetPdf417ExtraMetadata() {
        return (this.pdf417ExtraMetadata!= null);
    }

    /**
     * Gets the value of the upcEanExtension property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUpcEanExtension() {
        if (upcEanExtension == null) {
            return "";
        } else {
            return upcEanExtension;
        }
    }

    /**
     * Sets the value of the upcEanExtension property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUpcEanExtension(String value) {
        this.upcEanExtension = value;
    }

    public boolean isSetUpcEanExtension() {
        return (this.upcEanExtension!= null);
    }

    /**
     * Gets the value of the suggestedPrice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSuggestedPrice() {
        if (suggestedPrice == null) {
            return "";
        } else {
            return suggestedPrice;
        }
    }

    /**
     * Sets the value of the suggestedPrice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSuggestedPrice(String value) {
        this.suggestedPrice = value;
    }

    public boolean isSetSuggestedPrice() {
        return (this.suggestedPrice!= null);
    }

    /**
     * Gets the value of the issueNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIssueNumber() {
        if (issueNumber == null) {
            return "";
        } else {
            return issueNumber;
        }
    }

    /**
     * Sets the value of the issueNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIssueNumber(String value) {
        this.issueNumber = value;
    }

    public boolean isSetIssueNumber() {
        return (this.issueNumber!= null);
    }

    /**
     * Gets the value of the orientation property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOrientation() {
        if (orientation == null) {
            return "";
        } else {
            return orientation;
        }
    }

    /**
     * Sets the value of the orientation property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOrientation(String value) {
        this.orientation = value;
    }

    public boolean isSetOrientation() {
        return (this.orientation!= null);
    }

    /**
     * Gets the value of the other property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOther() {
        if (other == null) {
            return "";
        } else {
            return other;
        }
    }

    /**
     * Sets the value of the other property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOther(String value) {
        this.other = value;
    }

    public boolean isSetOther() {
        return (this.other!= null);
    }

    /**
     * Gets the value of the possibleCountry property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPossibleCountry() {
        if (possibleCountry == null) {
            return "";
        } else {
            return possibleCountry;
        }
    }

    /**
     * Sets the value of the possibleCountry property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPossibleCountry(String value) {
        this.possibleCountry = value;
    }

    public boolean isSetPossibleCountry() {
        return (this.possibleCountry!= null);
    }

}

==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/BarcodeType.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BarcodeType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="BarcodeType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/extraction/barcode}PositionedContentElementType">
 *       <attGroup ref="{http://schema.webpdf.de/1.0/extraction/barcode}optionalBarcodeAttributes"/>
 *       <attribute name="type" use="required" type="{http://schema.webpdf.de/1.0/extraction/barcode}BarcodeEncodingsType" />
 *       <attribute name="page" default="1">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BarcodeType")
public class BarcodeType
    extends PositionedContentElementType
{

    @XmlAttribute(name = "type", required = true)
    protected BarcodeEncodingsType type;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "errorCorrectionLevel")
    protected String errorCorrectionLevel;
    @XmlAttribute(name = "segmentIndex")
    protected String segmentIndex;
    @XmlAttribute(name = "isLastSegment")
    protected String isLastSegment;
    @XmlAttribute(name = "optionalData")
    protected String optionalData;
    @XmlAttribute(name = "fileId")
    protected String fileId;
    @XmlAttribute(name = "structuredAppendParity")
    protected String structuredAppendParity;
    @XmlAttribute(name = "structuredAppendSequence")
    protected String structuredAppendSequence;
    @XmlAttribute(name = "pdf417ExtraMetadata")
    protected String pdf417ExtraMetadata;
    @XmlAttribute(name = "upcEanExtension")
    protected String upcEanExtension;
    @XmlAttribute(name = "suggestedPrice")
    protected String suggestedPrice;
    @XmlAttribute(name = "issueNumber")
    protected String issueNumber;
    @XmlAttribute(name = "orientation")
    protected String orientation;
    @XmlAttribute(name = "other")
    protected String other;
    @XmlAttribute(name = "possibleCountry")
    protected String possibleCountry;

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link BarcodeEncodingsType }
     *     
     */
    public BarcodeEncodingsType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link BarcodeEncodingsType }
     *     
     */
    public void setType(BarcodeEncodingsType value) {
        this.type = value;
    }

    public boolean isSetType() {
        return (this.type!= null);
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  1;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the errorCorrectionLevel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorCorrectionLevel() {
        if (errorCorrectionLevel == null) {
            return "";
        } else {
            return errorCorrectionLevel;
        }
    }

    /**
     * Sets the value of the errorCorrectionLevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorCorrectionLevel(String value) {
        this.errorCorrectionLevel = value;
    }

    public boolean isSetErrorCorrectionLevel() {
        return (this.errorCorrectionLevel!= null);
    }

    /**
     * Gets the value of the segmentIndex property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSegmentIndex() {
        if (segmentIndex == null) {
            return "";
        } else {
            return segmentIndex;
        }
    }

    /**
     * Sets the value of the segmentIndex property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSegmentIndex(String value) {
        this.segmentIndex = value;
    }

    public boolean isSetSegmentIndex() {
        return (this.segmentIndex!= null);
    }

    /**
     * Gets the value of the isLastSegment property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsLastSegment() {
        if (isLastSegment == null) {
            return "";
        } else {
            return isLastSegment;
        }
    }

    /**
     * Sets the value of the isLastSegment property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsLastSegment(String value) {
        this.isLastSegment = value;
    }

    public boolean isSetIsLastSegment() {
        return (this.isLastSegment!= null);
    }

    /**
     * Gets the value of the optionalData property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOptionalData() {
        if (optionalData == null) {
            return "";
        } else {
            return optionalData;
        }
    }

    /**
     * Sets the value of the optionalData property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOptionalData(String value) {
        this.optionalData = value;
    }

    public boolean isSetOptionalData() {
        return (this.optionalData!= null);
    }

    /**
     * Gets the value of the fileId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFileId() {
        if (fileId == null) {
            return "";
        } else {
            return fileId;
        }
    }

    /**
     * Sets the value of the fileId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFileId(String value) {
        this.fileId = value;
    }

    public boolean isSetFileId() {
        return (this.fileId!= null);
    }

    /**
     * Gets the value of the structuredAppendParity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStructuredAppendParity() {
        if (structuredAppendParity == null) {
            return "";
        } else {
            return structuredAppendParity;
        }
    }

    /**
     * Sets the value of the structuredAppendParity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStructuredAppendParity(String value) {
        this.structuredAppendParity = value;
    }

    public boolean isSetStructuredAppendParity() {
        return (this.structuredAppendParity!= null);
    }

    /**
     * Gets the value of the structuredAppendSequence property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStructuredAppendSequence() {
        if (structuredAppendSequence == null) {
            return "";
        } else {
            return structuredAppendSequence;
        }
    }

    /**
     * Sets the value of the structuredAppendSequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStructuredAppendSequence(String value) {
        this.structuredAppendSequence = value;
    }

    public boolean isSetStructuredAppendSequence() {
        return (this.structuredAppendSequence!= null);
    }

    /**
     * Gets the value of the pdf417ExtraMetadata property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPdf417ExtraMetadata() {
        if (pdf417ExtraMetadata == null) {
            return "";
        } else {
            return pdf417ExtraMetadata;
        }
    }

    /**
     * Sets the value of the pdf417ExtraMetadata property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPdf417ExtraMetadata(String value) {
        this.pdf417ExtraMetadata = value;
    }

    public boolean isSetPdf417ExtraMetadata() {
        return (this.pdf417ExtraMetadata!= null);
    }

    /**
     * Gets the value of the upcEanExtension property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUpcEanExtension() {
        if (upcEanExtension == null) {
            return "";
        } else {
            return upcEanExtension;
        }
    }

    /**
     * Sets the value of the upcEanExtension property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUpcEanExtension(String value) {
        this.upcEanExtension = value;
    }

    public boolean isSetUpcEanExtension() {
        return (this.upcEanExtension!= null);
    }

    /**
     * Gets the value of the suggestedPrice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSuggestedPrice() {
        if (suggestedPrice == null) {
            return "";
        } else {
            return suggestedPrice;
        }
    }

    /**
     * Sets the value of the suggestedPrice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSuggestedPrice(String value) {
        this.suggestedPrice = value;
    }

    public boolean isSetSuggestedPrice() {
        return (this.suggestedPrice!= null);
    }

    /**
     * Gets the value of the issueNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIssueNumber() {
        if (issueNumber == null) {
            return "";
        } else {
            return issueNumber;
        }
    }

    /**
     * Sets the value of the issueNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIssueNumber(String value) {
        this.issueNumber = value;
    }

    public boolean isSetIssueNumber() {
        return (this.issueNumber!= null);
    }

    /**
     * Gets the value of the orientation property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOrientation() {
        if (orientation == null) {
            return "";
        } else {
            return orientation;
        }
    }

    /**
     * Sets the value of the orientation property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOrientation(String value) {
        this.orientation = value;
    }

    public boolean isSetOrientation() {
        return (this.orientation!= null);
    }

    /**
     * Gets the value of the other property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOther() {
        if (other == null) {
            return "";
        } else {
            return other;
        }
    }

    /**
     * Sets the value of the other property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOther(String value) {
        this.other = value;
    }

    public boolean isSetOther() {
        return (this.other!= null);
    }

    /**
     * Gets the value of the possibleCountry property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPossibleCountry() {
        if (possibleCountry == null) {
            return "";
        } else {
            return possibleCountry;
        }
    }

    /**
     * Sets the value of the possibleCountry property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPossibleCountry(String value) {
        this.possibleCountry = value;
    }

    public boolean isSetPossibleCountry() {
        return (this.possibleCountry!= null);
    }

}
